---
slug: /error-code-22998-30926-38104-38105
---

# 22998, 30926, 38104, 38105

This section describes the error codes related to BLOB and CLOB.

## ERROR 22998 (HY000) : CLOB or NCLOB in multibyte character set not supported

* seekdb error code: 22998

* Cause: The SQL string function does not support the `CLOB` or `NCLOB` data type.

* Solution: Use the relevant functions in the `DBMS_LOG` package.

## ERROR 30926 (HY000) : unable to get a stable set of rows in the source tables

* seekdb error code: 30926

* Cause: The DML statement contains a non-deterministic `WHERE` clause, which prevents the generation of a stable set of rows.

* Solution: Remove the non-deterministic condition and re-execute the DML statement.

## ERROR 38104 (HY000) : Columns referenced in the ON Clause cannot be updated:'%.\*s'.'%.\*s'

* seekdb error code: 38104

* Cause: The columns referenced in the `ON` clause cannot be updated.

## ERROR 38105 (HY000) : specified row no longer exists

* seekdb error code: 38105

* Cause: The specified row was deleted by another user after the operation started.

* Solution: Re-execute the operation to handle other data rows.